@@ -1,7 +1,7 @@
 /*
  * nvidia-cfg
  *
- * Copyright (c) 2004  NVIDIA Corp.  All rights reserved.
+ * Copyright (c) 2004-2025  NVIDIA Corp.  All rights reserved.
  *
  * NOTICE TO USER:   The source code  is copyrighted under  U.S. and
  * international laws. NVIDIA, Corp. of Santa Clara, California owns
@@ -15,7 +15,7 @@
  * tion and  internal comments to the code,  notices to the end user
  * as follows:
  *
- * Copyright (c) 2004 NVIDIA Corp.  NVIDIA design patents pending in
+ * Copyright (c) 2004-2025 NVIDIA Corp.  NVIDIA design patents pending in
  * the U.S. and foreign countries.
  *
  * NVIDIA CORP.  MAKES  NO REPRESENTATION  ABOUT  THE SUITABILITY OF
@@ -167,6 +167,16 @@ typedef enum {
 
 
 
+/*
+ * NvCfgProgressTickCallbackProc - callback function type for reporting
+ * progress on firmware flashing. progress is a float value between 0.0
+ * and 1.0. reset is a NvCfgBool that is NVCFG_TRUE if the flash operation
+ * is being reset.
+ */
+typedef void (*NvCfgProgressTickCallbackProc)(float progress, NvCfgBool reset);
+
+
+
 /*
  * nvCfgGetDevices() - retrieve an array of NvCfgDevice's indicating
  * what PCI devices are present on the system.  On success, NVCFG_TRUE
@@ -446,6 +456,18 @@ NvCfgBool nvCfgFlashGSyncDevice(NvCfgGSyncHandle handle, int format,
                                 int size);
 
 
+/*
+ * nvCfgFlashGSyncDeviceWithProgress() - extended version of nvCfgFlashGSyncDevice()
+ * that allows for progress callback during firmware flashing. The progressCallback
+ * function is called periodically during the flash operation to report
+ * progress.
+ */
+
+NvCfgBool nvCfgFlashGSyncDeviceWithProgress(NvCfgGSyncHandle handle, int format,
+                                            const unsigned char *newFirmwareImage, int size,
+                                            NvCfgProgressTickCallbackProc progressCallback);
+
+
 /*
  * nvCfgDumpDisplayPortAuxLog() - dump the DisplayPort AUX channel log to the
  * system log. On success, NVCFG_TRUE will be returned. On failure, NVCFG_FALSE
@@ -453,4 +475,22 @@ NvCfgBool nvCfgFlashGSyncDevice(NvCfgGSyncHandle handle, int format,
  */
 NvCfgBool nvCfgDumpDisplayPortAuxLog(NvCfgDeviceHandle handle);
 
+/*
+ * nvCfgEnableUvmPersistence() - Enable UVM Persistence mode.
+ * On success, zero will be returned. On failure, non zero
+ * value will be returned.
+ * This API is for internal use only and will be removed
+ * in a future release.
+ */
+unsigned int nvCfgEnableUVMPersistence(NvCfgDeviceHandle handle);
+
+/*
+ * nvCfgDisableUVMPersistence() - Disable UVM Persistence mode.
+ * On success, zero will be returned. On failure, non-zero
+ * value will be returned.
+ * This API is for internal use only and will be removed
+ * in a future release.
+ */
+unsigned int nvCfgDisableUVMPersistence(NvCfgDeviceHandle handle);
+
 #endif /* __NVIDIA_CFG__ */
